#!/bin/sh
echo "Content-Type: text/plain"
echo ""

echo "hello, world."
pwd
env

